from flask import Flask, Response, render_template, request, abort
from .dbutil import SQLiteHelper
import time

app = Flask(__name__, static_folder='../static', template_folder='../templates')
db_helper = SQLiteHelper('jiangjinjiu.db')


def ip_restriction(allowed_ips):
    def decorator(f):
        def wrapped_function(*args, **kwargs):
            client_ip = request.remote_addr

            # 如果允许所有 IP，则跳过检查
            if allowed_ips == ['*']:
                return f(*args, **kwargs)

            if client_ip not in allowed_ips:
                abort(403)  # 返回 403 Forbidden 状态码
            return f(*args, **kwargs)
        return wrapped_function
    return decorator

ALLOWED_IPS = ['192.168.1.1', '127.0.0.1']

@app.route('/')
@ip_restriction(ALLOWED_IPS)
def index():
    return render_template('index.html')


@app.route('/0/<string:data>', methods=['POST', 'GET'])
@app.route('/0/', methods=['POST', 'GET'])
def input(data=None):
    print(data)
    return "0"


@app.route('/1/<string:data>', methods=['POST', 'GET'])
@app.route('/1/', methods=['POST', 'GET'])
def output(data=None):
    print(data)
    return "1"


@app.route('/2/<string:data>', methods=['POST', 'GET'])
@app.route('/2/', methods=['POST', 'GET'])
def flinks_input(data=None):
    db_helper.execute_non_query("INSERT INTO flinks (name, status) VALUES (?, ?)", (data, 25))
    return "2"


@app.route('/3/<string:data>', methods=['POST', 'GET'])
@app.route('/3/', methods=['POST', 'GET'])
def flinks_output(data=None):
    print(data)
    select_sql = "SELECT * FROM flinks"
    rows = db_helper.execute_query(select_sql)
    for row in rows:
        print(row)
    return "3"


@app.route('/4/<string:data>', methods=['POST', 'GET'])
@app.route('/4/', methods=['POST', 'GET'])
def do_econtract(data=None):
    print(data)
    return "6"


@app.route('/5', methods=['POST', 'GET'])
def chat():
    return render_template('chat.html')


messages = []
users = set()


@app.route('/5/output')
def message_output():
    uid = request.args.get("uid")
    users.add(uid)
    print("mess1111s=====", uid)

    def event_stream(uid):
        while True:
            if len(messages) > 0:
                for s1 in messages[:]:
                    if uid in s1:
                        yield 'data: {}\n\n'.format(s1)
                        messages.remove(s1)
            time.sleep(1)

    return Response(event_stream(uid), content_type='text/event-stream')


@app.route('/5/input/<message>')
def message_input(message):
    uid = request.args.get("uid")
    for user in users:
        messages.append(user + " >> " + message)
    return "Message sent!"


@app.route('/6/<string:data>', methods=['POST', 'GET'])
@app.route('/6/', methods=['POST', 'GET'])
def do_epay(data=None):
    print(data)
    return "5"


def main():
    app.run(debug=True, host='0.0.0.0', port=8080, threaded=True)


if __name__ == '__main__':
    main()
