from sqlalchemy import create_engine, Column, Integer, String
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

# 创建数据库引擎
engine = create_engine('sqlite:///jiangjinjiu.db', echo=True)

# 创建基类
Base = declarative_base()

# 定义数据模型
class User(Base):
    __tablename__ = 'users'

    id = Column(Integer, primary_key=True)
    name = Column(String)
    age = Column(Integer)

    def __repr__(self):
        return f"<User(name='{self.name}', age={self.age})>"

# 创建表结构
Base.metadata.create_all(engine)

# 创建会话
Session = sessionmaker(bind=engine)
session = Session()

# 添加新用户
new_user = User(name='Alice', age=30)
session.add(new_user)
session.commit()

# 查询用户
users = session.query(User).all()
for user in users:
    print(user)

# 更新用户信息
user_to_update = session.query(User).filter_by(name='Alice').first()
if user_to_update:
    user_to_update.age = 31
    session.commit()

# 删除用户
user_to_delete = session.query(User).filter_by(name='Alice').first()
if user_to_delete:
    session.delete(user_to_delete)
    session.commit()

# 关闭会话
session.close()